Features
********


This section describes all features that are shipped with this package.

Scenario Features
=================

.. autoclass:: balderhub.auth.lib.scenario_features.UserLoginFeature
    :members:

Role Features
-------------

.. autoclass:: balderhub.auth.lib.scenario_features.role.BaseRoleFeature
    :members:

.. autoclass:: balderhub.auth.lib.scenario_features.role.TokenRoleFeature
    :members:

.. autoclass:: balderhub.auth.lib.scenario_features.role.UserRoleFeature
    :members:

Setup Features
==============

.. note::
    This package does not provide any setup features.

.. todo add your features with .. autoclass
    .. autoclass:: balderhub.auth.lib.setup_features.MySetupFeature
        :members: